@@ -1,5 +1,5 @@
 package File::Collector ;
-$File::Collector::VERSION = '0.024';
+$File::Collector::VERSION = '0.025';
 use strict; use warnings;
 
 use Carp;
@@ -352,7 +352,9 @@ sub _generate_short_names {
 
   if (@files) {
     foreach my $file ( @files, $file ) {
-      $s->{_files}{all}{$file}{short_path} = $file =~ s/$longest_string//r;
+      my $tfile = $file;
+      $tfile =~ s/$longest_string//;
+      $s->{_files}{all}{$file}{short_path} = $tfile;
     }
   } else {
     $s->{_files}{all}{$file}{short_path} = $file;
@@ -414,7 +416,7 @@ sub _get_args {
 }
 
 1; # Magic true value
-# ABSTRACT: Collects files and sets up file Processors
+# ABSTRACT: Base class for custom File::Collector classes for classifying files and calling File::Collector::Processor methods for processing files
 
 __END__
 
@@ -422,11 +424,11 @@ __END__
 
 =head1 NAME
 
-File::Collector - Collects files and sets up file Processors
+File::Collector - Base class for custom File::Collector classes for classifying files and calling File::Collector::Processor methods for processing files
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 OVERVIEW
 
